Relay SDK Reference Docs
========================


These are auto-generated docs for the current version of the Python SDK

----

Client
------

.. automodule:: relay_sdk.client
   :members:
   :exclude-members: MetadataAPIAdapter

----

Events
------

.. automodule:: relay_sdk.events
   :members:

----

Interface
---------

.. automodule:: relay_sdk.interface
   :members:

----

Outputs
-------

.. automodule:: relay_sdk.outputs
   :members:

----

Webhook
-------

.. automodule:: relay_sdk.webhook
   :members: